
# Meta encoding adding time argument

Adds a time argument to the meta predicates. It can be used instead of [`meta.lp`](./meta.md) when the encoding requires time support.

::: src/metasp/encodings/meta-time.lp
    handler: asp
    options:
        glossary:
            include_references: false
            include_undocumented: false
        predicate_table:
            include_undocumented: false
        encodings:
            git_link: true
        start_level: 1
